@@ -61,7 +61,7 @@ class CbsClient(AbstractClient):
     def AttachDisks(self, request):
         """本接口（AttachDisks）用于挂载云硬盘。
 
-        * 支持批量操作，将多块云盘挂载到同一云主机。如果多个云盘存在不允许挂载的云盘，则操作不执行，以返回特定的错误码返回。
+        * 支持批量操作，将多块云盘挂载到同一云主机。如果多个云盘中存在不允许挂载的云盘，则操作不执行，返回特定的错误码。
         * 本接口为异步接口，当挂载云盘的请求成功返回时，表示后台已发起挂载云盘的操作，可通过接口[DescribeDisks](/document/product/362/16315)来查询对应云盘的状态，如果云盘的状态由“ATTACHING”变为“ATTACHED”，则为挂载成功。
 
         :param request: Request instance for AttachDisks.
@@ -543,10 +543,10 @@ class CbsClient(AbstractClient):
 
 
     def DetachDisks(self, request):
-        """本接口（DetachDisks）用于解挂云硬盘。
+        """本接口（DetachDisks）用于卸载云硬盘。
 
-        * 支持批量操作，解挂挂载在同一主机上的多块云盘。如果多块云盘存在不允许解挂载的云盘，则操作不执行，以返回特定的错误码返回。
-        * 本接口为异步接口，当请求成功返回时，云盘并未立即从主机解挂载，可通过接口[DescribeDisks](/document/product/362/16315)来查询对应云盘的状态，如果云盘的状态由“ATTACHED”变为“UNATTACHED”，则为解挂载成功。
+        * 支持批量操作，卸载挂载在同一主机上的多块云盘。如果多块云盘中存在不允许卸载的云盘，则操作不执行，返回特定的错误码。
+        * 本接口为异步接口，当请求成功返回时，云盘并未立即从主机卸载，可通过接口[DescribeDisks](/document/product/362/16315)来查询对应云盘的状态，如果云盘的状态由“ATTACHED”变为“UNATTACHED”，则为卸载成功。
 
         :param request: Request instance for DetachDisks.
         :type request: :class:`tencentcloud.cbs.v20170312.models.DetachDisksRequest`
@@ -601,6 +601,34 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def InquirePriceModifyDiskExtraPerformance(self, request):
+        """本接口（InquirePriceModifyDiskExtraPerformance）用于调整云硬盘额外性能询价。
+
+        :param request: Request instance for InquirePriceModifyDiskExtraPerformance.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.InquirePriceModifyDiskExtraPerformanceRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.InquirePriceModifyDiskExtraPerformanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("InquirePriceModifyDiskExtraPerformance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InquirePriceModifyDiskExtraPerformanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InquiryPriceCreateDisks(self, request):
         """本接口（InquiryPriceCreateDisks）用于创建云硬盘询价。
 
@@ -754,6 +782,36 @@ class CbsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyDiskExtraPerformance(self, request):
+        """本接口（ModifyDiskExtraPerformance）用于调整云硬盘额外的性能。
+
+        * 目前仅支持极速型SSD云硬盘（CLOUD_TSSD）和高性能SSD云硬盘(CLOUD_HSSD)。
+
+        :param request: Request instance for ModifyDiskExtraPerformance.
+        :type request: :class:`tencentcloud.cbs.v20170312.models.ModifyDiskExtraPerformanceRequest`
+        :rtype: :class:`tencentcloud.cbs.v20170312.models.ModifyDiskExtraPerformanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyDiskExtraPerformance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyDiskExtraPerformanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyDisksChargeType(self, request):
         """接口请求域名： cbs.tencentcloudapi.com 。
 
